% CALC_BETA calculates four matrices related to the transition from olivine
% to spinel:
%	beta: spinel fraction
%	betat: T-derivatives of beta
%	betaz: z-derivatives of beta
%	rho: density distribution (mantle)
% and heat production in case of oceanic subduction
%   H: heat production
%
% 	The equations of the stright indicating the initiation (z2) and end 
% (z1) of Ol-Sp transformation are taken form Schmeling et al., 1999, EPSL,
% 165, p55-66. Figure 1. 

% Script component of TEMSPOL: a MATLAB thermal model for deep subduction
% zones including major phase transformations.
% A.M. Negredo, J.L. Valera and E. Carminati (2002)

  T1=600;
  T2=700;
  for j=1:J
      z=(j-1)*Dz;
      for i=1:I
          z1=-2000/15*T(i,j)+depth-290000;
          z2=-2000/15*T(i,j)+depth-200000;
          z3=(z1-z2)/(T2-T1)*(T(i,j)-T1)+z2;
          if T(i,j)<T1  % olivine and metastable olivine fields
              beta(i,j)=0;
              betat(i,j)=0;
              betaz(i,j)=0;
          elseif T(i,j)<T2
              if z<z3 % vertical branch of phase transition
    	       	  beta(i,j)=(T(i,j)-T1)/(T2-T1);
    	          betat(i,j)=1/(T2-T1);
                  betaz(i,j)=0; 
              elseif z>z2    % olivine
                  beta(i,j)=0;
                  betat(i,j)=0;
                  betaz(i,j)=0;
              else    %z>3 & z<z2,  horizontal branch of phase transition
                  beta(i,j)=(z2-z)/(z2-z1);
                  betat(i,j)=-1/(15/2*90);
                  betaz(i,j)=-1/90000;
              end
          else  % T>=T2
              if z<z1 % spinel  
	              beta(i,j)=1;
	              betat(i,j)=0;
               	  betaz(i,j)=0;
              elseif z>z1 & z<z2   % horizontal branch of phase transition
	              beta(i,j)=(z2-z)/(z2-z1);
	              betat(i,j)=-1/(15/2*90);
	              betaz(i,j)=-1/90000;
              else   %z>z2  %olivine
	              beta(i,j)=0;
	              betat(i,j)=0;
	              betaz(i,j)=0;
              end
          end
      end
  end
  rho=(rhom+drho_olsp*beta).*(1-alpha*T);  
clear T1 T2 z
